PoolDiscoverer

Struct PoolDiscoverer 

pub struct PoolDiscoverer<MS, Target, Request>
where MS: MakeService<Target, Request>,
{ /* private fields */ }
A wrapper around MakeService that discovers a new service when load is high, and removes a service when load is low. See Pool.