pub struct Balance<D: Discover, Req> { /* private fields */ }Expand description
Distributes requests across inner services using the Power of Two Choices.
As described in the Finagle Guide:
The algorithm randomly picks two services from the set of ready endpoints and selects the least loaded of the two. By repeatedly using this strategy, we can expect a manageable upper bound on the maximum load of any server.
The maximum load variance between any two servers is bound by
ln(ln(n))wherenis the number of servers in the cluster.
Note that Balance requires that the Discover you use is Unpin in order to implement
Service. This is because it needs to be accessed from Service::poll_ready, which takes
&mut self. You can achieve this easily by wrapping your Discover in Box::pin before you
construct the Balance instance. For more details, see #319.
Implementations